@@ -15,6 +15,16 @@ NATYPES = {
   "logical" => "NA_LINT",
 }
 
+USEXBLAS = %w( gesvxx gerfsx la_gerfsx_extended la_geamv
+               la_gercond la_gercond_c la_gercond_x la_rpvgrw la_gerpvgrw sysvxx syrfsx
+               la_syrfsx_extended la_syamv la_syrcond la_syrpvgrw la_syrcond_c la_syrcond_x
+               posvxx porfsx la_porfsx_extended la_porcond la_porcond_c la_porcond_x
+               la_porpvgrw gbsvxx gbrfsx la_gbrfsx_extended
+               hesvxx herfsx la_herfsx_extended
+               la_heamv la_hercond_c la_hercond_x la_herpvgrw
+               la_gbamv la_gbrcond la_gbrcond_c la_gbrcond_x la_gbrpvgrw la_lin_berr larscl2
+               lascl2 la_wwaddw )
+
 
 TOPDIR = File.join(File.dirname(__FILE__), "..")
 
@@ -292,12 +302,16 @@ def create_code(name, flag, debug)
     raise "category is invalid: #{sub_type} (#{sub_name})"
   end
 
+  usexblas = USEXBLAS.include?(sub_name[1..-1])
+
   code << <<"EOF"
 
 static VALUE
 #{RBPREFIX}#{sub_name}(int argc, VALUE *argv, VALUE self){
 EOF
 
+  code << "#ifdef USEXBLAS\n" if usexblas
+
   dimdefs = Array.new
   (inputs+options+outputs).each{|aname|
     arg = args[aname]
@@ -696,8 +710,17 @@ EOF
     result = "rb_ary_new3(#{out.length}, #{out.collect{|op| RBPREFIX+op}.join(", ")})"
   end
 
-  code << <<"EOF"
+  if usexblas
+    code << <<"EOF"
   return #{result};
+#else
+  return Qnil;
+#endif
+EOF
+  else
+    code << "  return #{result};\n"
+  end
+    code << <<"EOF"
 }
 
 EOF
@@ -815,7 +838,10 @@ EOF
 EOF
 
     sub_names.each{|sname|
+      usexblas = USEXBLAS.include?(sname[1..-1])
+      file.print "#ifdef USEXBLAS\n" if usexblas
       file.print "extern void init_lapack_#{sname}(VALUE mLapack, VALUE sHelp, VALUE sUsage, VALUE #{RBPREFIX}ZERO);\n"
+      file.print "#endif\n" if usexblas
     }
 
     file.print <<"EOF"
@@ -836,7 +862,10 @@ void Init_lapack(){
 
 EOF
     sub_names.each{|sname|
+      usexblas = USEXBLAS.include?(sname[1..-1])
+      file.print "#ifdef USEXBLAS\n" if usexblas
       file.print "  init_lapack_#{sname}(mLapack, sHelp, sUsage, #{RBPREFIX}ZERO);\n"
+      file.print "#endif\n" if usexblas
     }
     file.print "}\n"
   }
