@@ -64,10 +64,6 @@ ARGS = {
   "spstf2" => {
     "work" => {:intent => "input", :type => "real"}
   },
-  "slarrf" => {
-    "clgapl" => {:intent => "input", :type => "real"},
-    "clgapr" => {:intent => "input", :type => "real"},
-  },
   "cheequb" => {
     "uplo" => {:intent => "input", :type => "char"},
     "work" => {:intent => "input", :type => "complex"}
@@ -918,7 +914,7 @@ SUBSTS["dlansp"] = {"lwork" => '(lsame_(&norm,"I") || lsame_(&norm,"1") || lsame
 %w(zlange zlanhs).each{|n| SUBSTS[n] = {"lwork" => 'lsame_(&norm,"I") ? n : 0'}}
 %w(spprfs dpprfs cpprfs zpprfs chpsv zhpsv sspsv dspsv cspsv zspsv stprfs dtprfs ctprfs ztprfs).each{|n| SUBSTS[n] = {"n" => 'ldb'}}
 SUBSTS["slasd0"] = {"m" => "sqre == 0 ? n : sqre == 1 ? n+1 : 0", "ldu" => "n", "ldvt" => "m"}
-SUBSTS["dlasd0"] = {"m" => "sqre == 0 ? n : sqre == 1 ? n+1 : 0", "ldu" => "n", "ldu" => "n", "ldvt" => "n"}
+SUBSTS["dlasd0"] = {"m" => "sqre == 0 ? n : sqre == 1 ? n+1 : 0", "ldu" => "n",  "ldvt" => "n"}
 SUBSTS["slasd3"] = {"ldu2" => "n", "n" => "nl + nr + 1", "ldvt2" => "n", "m" => "n+sqre"}
 SUBSTS["dlasd3"] = {"ldu2" => "n", "n" => "nl + nr + 1", "ldvt2" => "n", "m" => "n + sqre"}
 %w(slasda dlasda).each{|n| SUBSTS[n] = {"m" => "sqre == 0 ? n : sqre == 1 ? n+1 : 0", "ldu" => "n"}}
@@ -1178,7 +1174,7 @@ def read_file(fname)
   return {:subr => subr, :purpose => purpose, :args => args, :help => help}
 end
 
-def parse_file(fname)
+def parse_file(fname, debug)
   hash = read_file(fname)
   subr = hash[:subr]
   purpose = hash[:purpose]
@@ -1219,7 +1215,7 @@ def parse_file(fname)
     raise "arg_names is nil #{fname}"
   end
 
-  if @@debug
+  if debug
     p sub_name
     p arg_names
   end
@@ -1289,7 +1285,7 @@ def parse_file(fname)
     end
   }
 
-  if @debug
+  if debug
     pp ary
   end
 
@@ -1437,7 +1433,7 @@ def parse_file(fname)
         str.sub!(/(just )?as declared in the (in the )?calling (subroutine|procedure)\./,"")
         str.strip
         if  /^([^;]+); if ([^,]+), ([^;]+); if ([^,]+), (.+)$/ =~ str
-          if @@debug
+          if debug
             p 100
           end
           v = get_vname($1)
@@ -1447,7 +1443,7 @@ def parse_file(fname)
           v1 = get_vname($5)
           str = "#{cond0} ? #{v0} : #{cond1} ? #{v1} : #{v}"
         elsif /^If ([^\,]+)\,\s+([^;]+); if ([^\,]+)\,\s+(.*)$/ =~ str || /^If ([^\,]+)\,\s+([^\.]+)\. If ([^\,]+)\,\s+(.*)$/ =~ str
-          if @@debug
+          if debug
             p 110
           end
           v0 = get_vname($1)
@@ -1456,7 +1452,7 @@ def parse_file(fname)
           cond1 = get_cond($4)
           str = "#{cond0} ? #{v0} : #{cond1} ? #{v1} : 0"
         elsif /^([^\,]+)\, and if ([^\,]+)\, (?:then )?(.*)$/ =~ str || /^([^;]+); if ([^\,]+)\, (?:then )?(.*)$/ =~ str
-          if @@debug
+          if debug
             p 120
           end
           v0 = get_vname($1)
@@ -1464,7 +1460,7 @@ def parse_file(fname)
           v1 = get_vname($3)
           str = "#{cond1} ? #{v1} : #{v0}"
         elsif /^(.+?) if ([^;]+); (.+?) otherwise$/ =~ str
-          if @@debug
+          if debug
             p 130
           end
           v0 = get_vname($1)
@@ -1472,7 +1468,7 @@ def parse_file(fname)
           v = get_vname($3)
           str = "#{cond0} ? #{v0} : #{v}"
         elsif /^If ([^,]+), then\s+(.+?)\.\s+In any case, (.+)$/ =~ str
-          if @@debug
+          if debug
             p 140
           end
           cond0 = get_cond($1)
@@ -1480,7 +1476,7 @@ def parse_file(fname)
           v = get_vname($3)
           str = "#{cond0} ? #{v0} : #{v}"
         elsif  /^([^;]+); and if ([^,]+), (.+)$/ =~ str
-          if @@debug
+          if debug
             p 150
           end
           v = get_vname($1)
@@ -1488,24 +1484,24 @@ def parse_file(fname)
           v0 = get_vname($3)
           str = "#{cond0} ? #{v0} : #{v}"
         elsif /^(.+?) \.LE\. #{un}$/ =~ str
-          if @@debug
+          if debug
             p 160
           end
           str = get_vname($1)
         elsif /^If ([^,]+), then\s+(.+)$/ =~ str
-          if @@debug
+          if debug
             p 170
           end
           cond0 = get_cond($1)
           v0 = get_vname($2)
           str = "#{cond0} ? #{v0} : 0"
         elsif (/^[sd]bdsdc$/ =~ sub_name && /^ld(u|vt)$/ =~ name)
-          if @@debug
+          if debug
             p 180
           end
           str = 'lsame_(&compq,"I") ? MAX(1,n) : 0'
         else
-          if @@debug
+          if debug
             p 190
           end
           if /^[sdcz]laqr[23]$/ =~ sub_name && name == "ldwv"
@@ -1569,39 +1565,39 @@ def parse_file(fname)
           if /^\([^;]+\); (\(.+?\) if [A-Z\d]+ = .+? or \(.+?\) if [A-Z\d]+ = .+)$/ =~ str
             str = $1
           end
-          if @@debug
+          if debug
             p name
             p str
           end
           while (str && str!="")
             if (/^(?:and )?\((.*?)\)\s+if\s+([^\,\;]+)[\,\;]\s+(.*)$/ =~ str) && (dim = $1.strip) && (cond = $2.strip) && (str_tmp = $3.strip) && (/ if .* if / !~ cond) && (/\([^\)]+$/ !~ cond) && (/=/ !~ dim)
-              if @@debug
+              if debug
                 p 1
               end
               str = str_tmp
             elsif (/^\(([^;]+?)\)\s+if\s+(.+?)\s+(?:or|and)\s+(\(.*\) if.*)$/ =~ str) || (/^\(([^;]+?)\)\s+if\s+(.+?)\s+(\(.*\)\s+if.*)$/ =~ str)
-              if @@debug
+              if debug
                 p 2
               end
               dim = $1
               cond = $2.strip
               str = $3.strip
             elsif /^If ([^\,]+)\,\s+([^;\.]+)[;\.]?(.*)$/ =~ str
-              if @@debug
+              if debug
                 p 2.5
               end
               cond = $1.strip
               dim = $2
               str = $3.strip
             elsif /^\((.*?)\)\s+if\s+([^\,]+)\, (\(.*\) otherwise)$/ =~ str
-              if @@debug
+              if debug
                 p 3
               end
               dim = $1.strip
               cond = $2.strip
               str = $3.strip
             elsif (/^(?:and )?\((.+?)\)\s+if\s+(.*)$/ =~ str) && (dim = $1.strip) && (cond = $2.strip) && (/if/ !~ dim) && (/ if /i !~ cond) && (/^[^\(]+\)/ !~ dim)
-              if @@debug
+              if debug
                 p 4
               end
               str = nil
@@ -1610,7 +1606,7 @@ def parse_file(fname)
               cond = $2
               str = $'
             elsif /^(.*?)\s+otherwise$/ =~ str && (dim = $1.strip) && (/ if / !~ dim)
-              if @@debug
+              if debug
                 p 5
               end
               if cond == "not referenced"
@@ -1623,7 +1619,7 @@ def parse_file(fname)
               flag = false
               break
             elsif /^\((.+?)\);?\s+If ([A-Z_\d]+ = [^\,]+)\, (then )?#{name.upcase} is not referenced.?$/ =~ str
-              if @@debug
+              if debug
                 p 6
               end
               dims = get_dims($1)
@@ -1634,7 +1630,7 @@ def parse_file(fname)
               flag = false
               break
             elsif /^\((.+?)\); Not referenced if (.*)$/ =~ str
-              if @@debug
+              if debug
                 p 6.5
               end
               v0 = get_vname($1)
@@ -1643,7 +1639,7 @@ def parse_file(fname)
               flag = false
               break
             elsif /\((.+?)\)\, where ([A-Z\d]+) >= ([A-Z\d]+) when ([^;]+); otherwise, #{name.upcase} is not referenced\.?$/ =~ str
-              if @@debug
+              if debug
                 p 7
               end
               dims = get_dims($1)
@@ -1654,7 +1650,7 @@ def parse_file(fname)
               flag = false
               break
             elsif /\((.+)\)[\.\,] where ([A-Z\d]+) = (.+)\.?$/ =~ str
-              if @@debug
+              if debug
                 p 8
               end
               dims = get_dims($1)
@@ -1664,7 +1660,7 @@ def parse_file(fname)
               flag = false
               break
             elsif /^(?:and )?(not referenced) if (.+).?$/ =~ str
-              if @@debug
+              if debug
                 p 9
               end
               dim = $1
@@ -1677,7 +1673,7 @@ def parse_file(fname)
               break
             else
               if /^\((.+?)\) (.+?) = (.+?) (?:when|if) ([^,]+), and (.+?) when (.+)$/ =~ str
-                if @@debug
+                if debug
                   p 10
                 end
                 dim = $1
@@ -1694,7 +1690,7 @@ def parse_file(fname)
                 flag = false
                 break
               elsif /^\((.+?)\) (.+?) = (.+?) (?:when|if) ([^,]+), and (.+?) otherwise.?$/ =~ str
-                if @@debug
+                if debug
                   p 11
                 end
                 dim = $1
@@ -1710,7 +1706,7 @@ def parse_file(fname)
                 flag = false
                 break
               elsif /^\((.+?)\);\s+[Ii]f ([A-Z_\d]+ = [^\,]+)\, ([A-Z_\d]+) \>?= ([^\.]+)\.\s+Otherwise\, ([A-Z_\d]+) \>?= (.*)$/ =~ str
-                if @@debug
+                if debug
                   p 14
                 end
                 dim = $1
@@ -1729,7 +1725,7 @@ def parse_file(fname)
                 break
               end
               if /^\((.+?)\)\.\s+[Ii]f ([A-Z_\d]+ = [^\,]+)\, ([A-Z_\d]+) = ([A-Z_\d]+); if ([A-Z_\d]+ = [^\,]+), ([A-Z_\d]+) = ([A-Z_\d]+)$/ =~ str
-                if @@debug
+                if debug
                   p 13
                 end
                 dim = $1
@@ -1740,7 +1736,7 @@ def parse_file(fname)
                 c10 = $6.downcase
                 c11 = $7.downcase
               elsif /\((.+?)\);? ([A-Z_\d]+) = (.+?) if ([^;]+); ([A-Z_\d]+) = (.+?) if (.+)$/ =~ str
-                if @@debug
+                if debug
                   p 13
                 end
                 dim = $1
@@ -1865,7 +1861,7 @@ def parse_file(fname)
     args["iloz"] = {:type => "integer", :intent => "input"}
     args["ihiz"] = {:type => "integer", :intent => "input"}
   end
-  if @@debug
+  if debug
     pp args
   end
 
@@ -1875,8 +1871,8 @@ def parse_file(fname)
 end
 
 
-def create_hash(fname)
-  hash = parse_file(fname)
+def create_hash(fname, debug)
+  hash = parse_file(fname, debug)
   if hash.nil?
     warn "skip #{fname}"
     return nil
@@ -1911,7 +1907,7 @@ def create_hash(fname)
   return hash
 end
 
-def generate_code(fnames)
+def generate_code(fnames, debug)
   nfnames = fnames.length
   sub_names = Array.new
   fnames.each_with_index{|fname,i|
@@ -1929,7 +1925,7 @@ def generate_code(fnames)
       next if get_md5sum(help) == md5sum && !@@force
     end
 
-    hash = create_hash(fname)
+    hash = create_hash(fname, debug)
     def hash.each
       [:name, :md5sum, :category].each do |k|
         yield(k, self[k])
@@ -1941,7 +1937,7 @@ def generate_code(fnames)
         yield(k, self[k])
       end
     end
-    p "write #{hash[:name]}" if @@debug
+    p "write #{hash[:name]}" if debug
     File.open(def_fname, "w") do |file|
       file.write hash.to_yaml
     end
@@ -1956,8 +1952,8 @@ end
 
 
 
-@@debug = ARGV.delete("--debug")
-@@force = ARGV.delete("--force")
+debug = ARGV.delete("--debug")
+force = ARGV.delete("--force")
 
 dname = ARGV[0] || raise("Usage: ruby #$0 path_to_lapack_src")
 if File.directory?(dname)
@@ -1967,6 +1963,6 @@ elsif File.file?(dname)
 #  @@debug = true
 end
 
-generate_code(fnames)
+generate_code(fnames, debug)
 
 
