@@ -62,35 +62,62 @@ unless find_library("lapack", nil)
   end
 end
 
-narray_dir = nil
-if s = ( Gem::Specification.find_all_by_name("narray")[0] || Gem::Specification.find_all_by_name("narray-bigmem")[0] )
-  if s.respond_to?(:exts_dir)
-    narray_dir = s.exts_dir + "/narray"
-    narray_dir = s.gem_dir+"/lib/narray" unless File.exist?(narray_dir)
-  else
-    narray_dir = s.extension_dir + "/narray"
-  end
-  narray_include = narray_dir
-  narray_lib = narray_dir
+na_path = RbConfig::CONFIG["sitearchdir"]
+begin
+  require "rubygems"
+  gem = true
+rescue LoadError
+  gem = false
 end
-
-unless narray_dir && File.exist?(narray_dir)
-  if Gem.respond_to?(:find_files)
-    require "rbconfig"
-    so = RbConfig::CONFIG["DLEXT"]
-    narray_include = File.expand_path(File.dirname(Gem.find_files("narray.h")[0]))
-    narray_lib = File.expand_path(File.dirname(Gem.find_files("narray." + so)[0]))
+if gem
+  if ( na_type = ENV["NARRAY_TYPE"] )
+    nas = [na_type]
   else
-    gem_home=(`gem environment GEM_HOME`).chomp
-    narray_dir = Dir.glob("#{gem_home}/gems/narray-*").sort[-1]
-    if narray_dir
-      narray_include = narray_lib = narray_dir
-    else
-      sitearchdir = RbConfig::CONFIG["sitearchdir"]
-      narray_include = narray_lib = [$sitearchdir, $sitearchdir]
+    nas = %w(narray numru-narray)
+  end
+  if Gem::Specification.respond_to?(:find_by_name)
+    nas.each do |na|
+      begin
+        if ( spec = Gem::Specification.find_by_name(na) )
+          na_type = na
+          na_path = spec.full_gem_path
+          case na_type
+          when "narray"
+            na_path = File.join(na_path, "src")
+          when "numru-narray"
+            na_path = File.join(na_path, "ext", "numru", "narray")
+          end
+          break
+        end
+      rescue LoadError
+      end
+    end
+  else
+    nas.each do |na|
+      if ( spec = Gem.source_index.find_name(na) ).any?
+        na_type = na
+        na_path = spec[0].full_gem_path
+        case na_type
+        when "narray"
+          na_path = File.join(na_path, "src")
+        when "numru-narray"
+          na_path = File.join(na_path, "ext", "numru", "narray")
+        end
+        break
+      end
     end
   end
 end
-dir_config('narray', narray_include, narray_lib)
+
+dir_config("narray", na_path, na_path)
+unless have_header("narray.h")
+  $stderr.print "narray.h does not found. Specify the path.\n"
+  $stderr.print "e.g., gem install ruby-lapack -- --with-narray-include=path\n"
+  exit(-1)
+end
+
+if have_func("zposvxx_")
+  $defs.each{|d| d.sub!("HAVE_ZPOSVXX_", "USEXBLAS")}
+end
 
 create_makefile("numru/lapack")
