@@ -7,7 +7,9 @@
 #ifndef F2C_INCLUDE
 #define F2C_INCLUDE
 
-#if defined(__alpha__) || defined(__sparc64__) || defined(__x86_64__) || defined(__ia64__)
+#include <stdint.h>
+
+#if UINTPTR_MAX == UINT64_MAX
 typedef int integer;
 typedef int logical;
 #else
@@ -22,7 +24,7 @@ typedef struct { doublereal r, i; } doublecomplex;
 #ifdef f2c_i2
 typedef short ftnlen;
 #else
-#if defined(__alpha__) || defined(__sparc64__) || defined(__x86_64__) || defined(__ia64__)
+#if UINTPTR_MAX == UINT64_MAX
 typedef int ftnlen;
 #else
 typedef long int ftnlen;
