@@ -8,7 +8,7 @@
 #define MIN(a,b) ((a) < (b) ? (a) : (b))
 #define LG(n) ((int)ceil(log((double)(n))/log(2.0)))
 
-extern logical lsame_(char *ca, const char *cb);
+extern logical lsame_(char *ca, char *cb);
 extern integer ilatrans_(char* trans);
 extern integer ilaenv_(integer* ispec, char* name, char* opts, integer* n1, integer* n2, integer* n3, integer* n4);
 
@@ -16,3 +16,9 @@ extern integer ilaenv_(integer* ispec, char* name, char* opts, integer* n1, inte
 static VALUE sHelp, sUsage;
 static VALUE rblapack_ZERO;
 
+/* for compatibility for NArray and NArray with bigmem patch */
+#ifndef NARRAY_BIGMEM
+typedef int    na_shape_t;
+#endif
+
+
